@@ -2,7 +2,7 @@ require 5.006;
 use strict;
 use warnings;
 package Email::Valid;
-$Email::Valid::VERSION = '1.200';
+$Email::Valid::VERSION = '1.201';
 # ABSTRACT: Check validity of Internet email addresses
 our (
   $RFC822PAT,
@@ -146,6 +146,7 @@ sub _net_dns_query {
 
   my @mx_entries = Net::DNS::mx($Resolver, $host);
 
+  # Check for valid MX records for $host
   if (@mx_entries) {
     foreach my $mx (@mx_entries) {
       my $mxhost = $mx->exchange;
@@ -157,6 +158,15 @@ sub _net_dns_query {
     }
   }
 
+  # Chceck for A record for $host
+  my @a_rrs = Net::DNS::rr($Resolver, $host, 'A');
+  if (@a_rrs) {
+    foreach my $a_rr (@a_rrs) {
+      return 1 unless $a_rr->type ne 'A';
+    }
+  }
+
+  # MX Check failed
   return $self->details('mx');
 }
 
@@ -713,7 +723,7 @@ Email::Valid - Check validity of Internet email addresses
 
 =head1 VERSION
 
-version 1.200
+version 1.201
 
 =head1 SYNOPSIS
 
